XDK Mobile para projetos Flutter.

## Funcionalidades

Comunicação com servidores (APIs) através dos Stores da XDK. Fluxo de autenticação.

## Configuração inicial

Dentro da sua aplicação flutter, você deve configurar a XDK. Segue um exemplo de uma aplicação flutter que utiliza a XDK:

````dart
class XApp extends StatelessWidget {
  XApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    // Inicializa a XDK.
    XDKSetup.init(IxMobileConfig(
      // Nome da aplicação.
        applicationName: 'XDK Mobile Test',
        // ID da aplicação, pode ser um nome simples, mas no padrão slug.
        applicationId: 'xdk-mobile-test',
        // BuildContext da aplicação atual.
        context: context,
        // Endereço base do servidor (API).
        baseUrl: 'https://itixti.com.br',
        // Configuração da segurança.
        securityConfig: IxMobileSecurityConfig(
            shouldUseAuthorizer: true, // Indica que deve usar o autorizador.
            useIxOAuth: true // Indica que deve usar a autenticação OAuth da ITIX.
        )
    ));
    // Configura as stores da aplicação.
    XDKSetup.addStores([ProductsStore(), CompaniesStore()]);

    // Se estiver usando autenticação, aqui obtemos o serviço de autenticação. 
    var authService = getService<AuthService>();

    // Dispara quando o usuário tiver logado. 
    authService.onUserLoggedIn.stream.listen((userInfo) {
      Navigator.pop(context); // Removendo loading.
      // Envia para a tela principal do sistema.
      Navigator.pushReplacement(context, MaterialPageRoute<void>(builder: (BuildContext context) {
        // Sempre que o contexto é alterado, precisamos avisar para a XDK.
        updateXDKConfigContext(context);
        return MyHomePage(title: 'XDK Mobile Test', userInfo: userInfo);
      }));
    });

    return const LoginPage(); // Usa a tela de login fornecida pela XDK.
  }
}
````
