import 'package:flutter/widgets.dart';

import 'fa_icon.dart';
import 'font_awesome_duotone.dart';

class FADuotoneIcon extends StatelessWidget {
  /// Ícone a ser exibido.
  final FontAwesomeDuotone icon;

  /// Tamanho da fonte do ícone.
  /// Usa o valor do [IconTheme], se houver. Se o [IconTheme] não foi informado,
  /// ou não tem um valor explícito, usa-se 24.0 como padrão.
  /// Se esse [FAIcon] está sendo colocado dentro de um [IconButton], então usamos o valor de [IconButton.iconSize].
  final double? size;

  /// Cor usada para o corpo principal do ícone.
  final Color? primaryColor;

  /// Cor usada na parte de destaque do ícone.
  final Color? secondaryColor;

  /// Usado para dar nome ao ícone no modo de acessibilidade.
  final String? semanticLabel;

  const FADuotoneIcon(
    this.icon, {
    Key? key,
    this.size,
    this.primaryColor,
    this.secondaryColor,
    this.semanticLabel,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Semantics(
      label: semanticLabel,
      child: Stack(
        children: <Widget>[
          FAIcon(
            icon,
            size: size,
            color: primaryColor,
            key: const Key("primaryGlyph"),
          ),
          FAIcon(
            icon.secondary,
            size: size,
            color: secondaryColor,
            key: const Key("secondaryGlyph"),
          ),
        ],
      ),
    );
  }
}
