import 'package:dart_json_mapper/dart_json_mapper.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';

/// Classe base para os armazenamentos de dados sigilosos.
abstract class BaseSecureStorage {
  @protected
  late final FlutterSecureStorage storage;

  @protected
  BaseSecureStorage() {
    storage = const FlutterSecureStorage();
  }

  /// Salva um registro usando a chave informada.
  Future<void> save<T>(T data, String key) async {
    var value = T == String ? data as String : JsonMapper.serialize(data);
    await storage.write(key: key, value: value);
  }

  /// Obtém um registro usando a chave informada.
  Future<T?> get<T>(String key) async {
    var item = await storage.read(key: key);

    if (T == String) {
      return item as T?;
    } else {
      return JsonMapper.deserialize<T>(item);
    }
  }

  /// Remove o(s) item(ns) informado(s).
  Future<void> remove([List<String> keys = const []]) async {
    for (var id in keys) {
      await storage.delete(key: id);
    }
  }

  /// Apaga os dados da tabela local.
  Future<void> clearAll() async {
    await storage.deleteAll();
  }
}
