import 'package:flutter/foundation.dart';
import 'package:localstorage/localstorage.dart';

/// Classe base para os armazenamentos.
abstract class BaseStorage {
  @protected
  late LocalStorage storage;

  static const _prefix = 'ix_';

  @protected
  BaseStorage(String tableName) {
    storage = LocalStorage('${_prefix}tableName');
  }

  /// Salva um registro usando a chave informada.
  Future<void> save<T>(T data, String key) async {
    await storage.setItem(key, data);
  }

  /// Obtém um registro usando a chave informada.
  T? get<T>(String key) {
    return storage.getItem(key) as T?;
  }

  /// Remove o(s) item(ns) informado(s).
  Future<void> remove([List<String> keys = const []]) async {
    for (var id in keys) {
      await storage.deleteItem(id);
    }
  }

  /// Apaga os dados da tabela local.
  Future<void> clearAll() async {
    await storage.clear();
  }
}
