import 'setup_token_request.dart';

/// Representa a configuração de segurança da biblioteca.
class IxMobileSecurityConfig {
  /// URL do serviço externo de autenticação.
  String? externalAuthUrl;

  /// URL para iniciar o processo de login quando usando OAuth da ITIX.
  String ixOAuthLoginUrl;

  /// URL para iniciar o processo de troca de senha quando usando OAuth da ITIX.
  String ixOAuthChangePasswordUrl;

  /// URL do administração de segurança quando usando OAuth da ITIX.
  String ixOAuthAdminUrl;

  /// URL para obter os dados do usuário quando usando OAuth da ITIX.
  String ixOAuthUserInfoUrl;

  /// Claim/Role que será utilizado para validar se o usuário é administrador.
  String adminAccessClaim;

  /// Path de troca de senha no servidor.
  String? passwordChangeServerPath;

  /// Indica se deve utilizar um autorizador para fazer a autenticação.
  bool shouldUseAuthorizer;

  /// Indica se deve usar cookies para realizar a autenticação das requisições.
  bool useCookieAuth;

  /// Indica se deve usar OAuth da ITIX para realizar a autenticação das requisições.
  bool useIxOAuth;

  /// Indica se deve obter as claims/roles do token JWT.
  /// Caso contrário, irá obter as claims/roles do endereço /userinfo.
  bool getClaimsFromToken;

  /// Gera um RequestModel que será enviado para realizar a autenticação e obter o token do usuário.
  SetupTokenRequest? setupTokenRequest;

  IxMobileSecurityConfig(
      {this.externalAuthUrl,
      this.ixOAuthLoginUrl = '/oauth/connect',
      this.ixOAuthChangePasswordUrl = '/oauth/change-password',
      this.ixOAuthAdminUrl = '/oauth/admin',
      this.ixOAuthUserInfoUrl = '/oauth/user-info',
      this.adminAccessClaim = 'admin',
      this.shouldUseAuthorizer = false,
      this.useCookieAuth = false,
      this.useIxOAuth = false,
      this.getClaimsFromToken = false,
      this.setupTokenRequest});
}
