import 'package:flutter/widgets.dart';

import '../abstractions/base_model.dart';
import 'enums/message_type.dart';
import 'message_events.dart';
import 'message_result.dart';

/// Representa uma mensagem.
class MessageModel extends BaseModel {
  /// Tipo da mensagem (alerta, informação, erro, etc).
  MessageTypeEnum type;

  /// Mensagem a ser exibida.
  String message;

  /// Informação adicional que será exibida na parte de baixo da notificação.
  String? additionalInfo;

  /// Título.
  String? title;

  /// Ícone customizado exibido na mensagem, seguindo o padrão font-awesome - fa(x) - fa-(icon),
  /// onde: x é a variação do ícones, podendo ser solid - fas, light - fal, regular - far, duotone - fad
  /// e icon é o nome do ícone do font-awesome. Ex: fal fa-home.
  String? customIconClass;

  /// Se o conteúdo for uma lista, os itens da lista devem ser informados aqui.
  List<String> listContent;

  /// Indica se o conteúdo é uma lista.
  bool hasList;

  /// Indica se deve abrir como modal.
  /// Caso contrário, irá abrir como uma notificação.
  bool isModal;

  /// Indica se deve exibir um loader ao fazer o request.
  bool showLoaderOnConfirm;

  /// Indica se deve exibir o botão de fechar.
  bool showCloseButton;

  /// Indica se deve exibir o ícone do notification.
  bool showNotificationIcon;

  /// Indica se a cor de fundo será mais clara.
  bool isLight;

  /// Indica se a notificação nao terá a cor de fundo preenchida.
  bool isOutline;

  /// Tempo que a notificação permanece visível.
  int timeout = 5000;

  /// Função executado após o clique do botão.
  Function(MessageResult)? callback;

  /// Eventos de interação com a mensagem.
  MessageEvents? events;

  /// Ações da mensagem.
  List<Widget>? actions;

  MessageModel(
      {required this.message,
      this.type = MessageTypeEnum.warning,
      this.additionalInfo,
      this.title,
      this.customIconClass,
      this.hasList = false,
      this.isModal = true,
      this.showLoaderOnConfirm = false,
      this.showCloseButton = true,
      this.showNotificationIcon = true,
      this.isLight = false,
      this.isOutline = false,
      this.timeout = 5000,
      this.callback,
      this.events,
      this.actions,
      this.listContent = const <String>[]});
}
