import 'dart:async';
import 'package:flutter/widgets.dart';

import '../models/enums/message_type.dart';
import '../models/message_model.dart';
import '../models/message_result.dart';

/// Envio de mensagens.
class MessageService {
  /// Disparado ao enviar uma mensagem.
  var onNewMessage = StreamController<MessageModel>();

  /// Envia uma mensagem de aviso.
  void sendWarning(String message,
      {String? title, Function(MessageResult)? callback, hasList = false, List<Widget>? actions, List<String>? list}) {
    _sendMessageBody(message, title, hasList: hasList, callback: callback, actions: actions, list: list);
  }

  /// Envia uma mensagem informativa.
  void sendInfo(String message,
      {String? title, Function(MessageResult)? callback, hasList = false, List<Widget>? actions, List<String>? list}) {
    _sendMessageBody(message, title, hasList: hasList, type: MessageTypeEnum.info, callback: callback, actions: actions, list: list);
  }

  /// Evnia uma mensagem de erro.
  void sendError(String message,
      {String? title, Function(MessageResult)? callback, hasList = false, List<Widget>? actions, List<String>? list}) {
    _sendMessageBody(message, title, hasList: hasList, type: MessageTypeEnum.error, callback: callback, actions: actions, list: list);
  }

  /// Envia uma mensagem de sucesso.
  void sendSuccess(String message,
      {String? title, Function(MessageResult)? callback, hasList = false, List<Widget>? actions, List<String>? list}) {
    _sendMessageBody(message, title, hasList: hasList, type: MessageTypeEnum.success, callback: callback, actions: actions, list: list);
  }

  /// Envia uma mensagem que solicita uma confirmação do usuário.
  void sendConfirmationRequest(String message,
      {String? title, Function(MessageResult)? callback, hasList = false, List<Widget>? actions, List<String>? list}) {
    _sendMessageBody(message, title, hasList: hasList, type: MessageTypeEnum.confirm, callback: callback, actions: actions, list: list);
  }

  /// Envia uma mensagem de aviso.
  void sendNotificationWarning(String message, {String? title, Function(MessageResult)? callback, hasList = false, List<Widget>? actions}) {
    _sendMessageBody(message, title, hasList: hasList, callback: callback, isModal: false, actions: actions);
  }

  /// Envia uma mensagem informativa.
  void sendNotificationInfo(String message, {String? title, Function(MessageResult)? callback, hasList = false, List<Widget>? actions}) {
    _sendMessageBody(message, title, hasList: hasList, type: MessageTypeEnum.info, callback: callback, isModal: false, actions: actions);
  }

  /// Evnia uma mensagem de erro.
  void sendNotificationError(String message, {String? title, Function(MessageResult)? callback, hasList = false, List<Widget>? actions}) {
    _sendMessageBody(message, title, hasList: hasList, type: MessageTypeEnum.error, callback: callback, isModal: false, actions: actions);
  }

  /// Envia uma mensagem de sucesso.
  void sendNotificationSuccess(String message, {String? title, Function(MessageResult)? callback, hasList = false, List<Widget>? actions}) {
    _sendMessageBody(message, title, hasList: hasList, type: MessageTypeEnum.success, callback: callback, isModal: false, actions: actions);
  }

  /// Envia uma mensagem de acordo com a configuração informada.
  void send(MessageModel message) {
    onNewMessage.add(message);
  }

  void _sendMessageBody(String message, String? title,
      {hasList = false,
      type = MessageTypeEnum.warning,
      Function(MessageResult)? callback,
      isModal = true,
      List<Widget>? actions,
      List<String>? list}) {
    send(MessageModel(
        message: message,
        type: type,
        title: title,
        hasList: hasList,
        callback: callback,
        isModal: isModal,
        actions: actions,
        listContent: list ?? <String>[]));
  }
}
