import 'dart:async';

import '../models/bad_server_response.dart';

/// Serviço responsável pela exibição de mensagens de retorno do backend.
///
/// Desse modo, quando o backend retornar na variável "error.error" do HTTP response uma string ou um array de key/value
/// e o [shouldDisplayAlertOnError] for igual a `true`, a XDK irá:
///
/// - Ou exibir um alert de erro com a string informada, quando o status code for 400, 500 ou 588 (o que é chamado de Business Exception).
/// - Ou exibir uma tabela com cada um dos itens, quando o status code for 588 e for retornado um array de key/value.
///
/// Caso não seja necessário esse comportamento padrão, é possível injetar o `ServerResponseService` no seu
/// componente e fazer um subscribe no [onError] que retornará um objeto de erro.
/// Caso seja necessário desabilitar o tratamento de erros padrão para a aplicação inteira,
/// basta injetar o serviço no seu app component e desabilitar a propriedade [shouldDisplayAlertOnError].
class ServerResponseService {
  /// Indica se a XDK possuirá um comportamento de erro customizado, fora do padrão descrito para a classe.
  /// Caso o sistema use o padrão em outras telas, é necessário fazer o `shouldDisplayAlertOnError = false` no `ngOnInit`
  /// e o `shouldDisplayAlertOnError = true` no `ngOnDestroy` do componente.
  bool shouldDisplayAlertOnError = true;

  /// Retorna um objeto com o erro que ocorreu.
  var onError = StreamController<BadServerResponse?>();

  /// Função responsavel por emitir a mensagem de erro vinda do backend.
  void setError(BadServerResponse? error) {
    onError.add(error);
  }
}
