import '../abstractions/base_secure_storage.dart';
import '../models/token_response.dart';
import '../models/user_info.dart';

/// Storage padrão para os dados de segurança.
class SecurityStorage extends BaseSecureStorage {
  static const _userTokenKey = '6788cd6fce16448c9d8c5e6ea488f4ba';
  static const _userInfoKey = 'f7685227b90e49789a3843a42b459ca0';
  static const _userCookieKey = '5ced7b75af0542819983b6972cd01b18';

  /// Salva o token do usuário logado.
  Future<void> saveUserToken(TokenResponse userToken) async {
    await save(userToken, _userTokenKey);
  }

  /// Obtém o token do usuário logado.
  Future<TokenResponse?> getUserToken() {
    return get<TokenResponse>(_userTokenKey);
  }

  /// Salva as informações do usuário logado.
  Future<void> saveUserInfo(UserInfo userInfo) async {
    await save(userInfo, _userInfoKey);
  }

  /// Obtém as informações do usuário logado.
  Future<UserInfo?> getUserInfo() {
    return get<UserInfo>(_userInfoKey);
  }

  /// Salva o cookie de autenticação do usuário logado.
  Future<void> saveUserCookie(String cookie) async {
    await save(cookie, _userCookieKey);
  }

  /// Obtém o cookie de autenticação do usuário logado.
  Future<String?> getUserCookie() {
    return get<String>(_userCookieKey);
  }
}
