import 'package:flutter/foundation.dart';

import '../../core/abstractions/base_entity_model.dart';
import '../models/request_model.dart';
import '../models/store_config.dart';
import 'base_search_store.dart';

/// Classe base para os stores que utilizam o CRUD completo.
abstract class BaseEntityStore<T extends BaseEntityModel> extends BaseSearchStore<T> {
  @protected
  BaseEntityStore(StoreConfig<T> config) : super(config);

  /// Obtém um registro.
  Future<T?> get(Object id, {Object? masterId}) async {
    return requestService.makeGet<T>(RequestModel(url: getUrl(config.actions.get, masterId), id: id, isAbsolute: isAbsoluteUrl));
  }

  /// Cria um novo registro.
  Future<T?> add(T data, {Object? masterId}) async {
    return requestService.makePost<T>(getRequestModel(config.actions.add, data: data, masterId: masterId));
  }

  /// Atualiza os dados de um registro.
  Future<T?> edit(T data, List<String> changedProperties, {Object? masterId}) async {
    return requestService.makePut<T>(RequestModel(
        url: '${getUrl(config.actions.edit, masterId)}/${data.id}',
        data: data,
        isAbsolute: isAbsoluteUrl,
        headers: {'IxFormChangedProperties': changedProperties.join(',')}));
  }

  /// Exclui o registro informado.
  Future<bool> remove(Object id, {Object? masterId}) async {
    return requestService.makeDelete(RequestModel(url: getUrl(config.actions.remove, masterId), id: id, isAbsolute: isAbsoluteUrl));
  }
}
