import 'package:flutter/foundation.dart';

import '../../core/models/search_request_model.dart';
import '../../core/models/search_response_model.dart';
import '../models/store_config.dart';
import 'base_store.dart';

/// Classe base para os stores que as funcionalidades de listagem.
abstract class BaseListStore<T> extends BaseStore<T> {
  @protected
  BaseListStore(StoreConfig<T> config) : super(config);

  /// Retorna uma lista de itens.
  Future<SearchResponseModel<T>> list(SearchRequestModel? request) async {
    request = request ?? SearchRequestModel();
    var resp = await requestService.makePost<SearchResponseModel<T>>(getRequestModel(config.actions.list, data: request));

    return resp ?? SearchResponseModel<T>();
  }

  /// Retorna uma lista de itens com base nos IDs informados.
  Future<List<T>> getByIds(List<Object> ids) async {
    var resp = await requestService.makePost<List<T>>(getRequestModel(config.actions.getByIds, data: ids));
    return resp ?? <T>[];
  }
}
