import 'package:flutter/foundation.dart';

import '../models/enums/http_content_type.dart';
import '../../core/models/search_request_model.dart';
import '../../core/models/search_response_model.dart';
import '../models/store_config.dart';
import 'base_list_store.dart';

/// Classe base para os stores que utilizam as funcionalidades de consulta.
abstract class BaseSearchStore<T> extends BaseListStore<T> {
  @protected
  bool forceCsvPost = false; // Obriga a utilizar POST em todas as requisições CSV.
  @protected
  bool forceCsvGet = false; // Obriga a utilizar GET em todas as requisições CSV.

  @protected
  BaseSearchStore(StoreConfig<T> config) : super(config);

  /// Pesquisa nos registros pelo termo informado.
  Future<SearchResponseModel<T>?> search(SearchRequestModel? request, Object? masterId) async {
    request = request ?? SearchRequestModel();
    return requestService.makePost<SearchResponseModel<T>>(getRequestModel(config.actions.search, data: request, masterId: masterId));
  }

  /// Obtém o arquivo CSV.
  Future<Object> getCsv(SearchRequestModel? request, Map<String, Object>? params) async {
    var requestModel = getRequestModel(config.actions.csv, data: request);
    requestModel.responseType = HttpContentType.arrayBuffer;
    requestModel.params = params ?? requestModel.params;

    if (forceCsvPost) {
      return requestService.makePost(requestModel);
    }

    if (forceCsvGet) {
      return requestService.makeGet(requestModel);
    }

    return request != null ? requestService.makePost(requestModel) : requestService.makeGet(requestModel);
  }

/*
  /// Faz o download do arquivo CSV no navegador do usuário.
  Future downloadCsv(String name, {bool openInPopup = false, SearchRequestModel? filters, Map<String, Object>? params}) async {
    var response = await getCsv(filters, params);

    // TODO: ver como fazer no dart.
    // const blob = new Blob([r], { type: 'text/csv' });
    // Tools.Utils.saveFile(blob, name, openInPopup);
  }
  */
}
