import 'dart:io';
import 'package:http_interceptor/http/interceptor_contract.dart';
import 'package:http_interceptor/models/request_data.dart';
import 'package:http_interceptor/models/response_data.dart';
import 'package:injector/injector.dart';

import '../../core/utils/xdk_config.dart';
import '../../core/services/security_service.dart';
import '../../core/utils/string_extensions.dart';
import '../../core/models/ix_mobile_config.dart';
import '../../core/storages/security_storage.dart';

/// Adiciona o cabeçalho de autenticação nas requisições HTTP com o token do usuário logado, se houver.
class AuthInterceptor implements InterceptorContract {
  late SecurityService _securityService;
  late SecurityStorage _securityStorage;
  late IxMobileConfig _xdkConfig;

  AuthInterceptor() {
    final injector = Injector.appInstance;
    _securityService = injector.get<SecurityService>();
    _securityStorage = injector.get<SecurityStorage>();
    _xdkConfig = getXDKConfig();
  }

  @override
  Future<RequestData> interceptRequest({required RequestData data}) async {
    if (_xdkConfig.securityConfig?.useCookieAuth ?? false) {
      data.headers[HttpHeaders.cookieHeader] = await _securityStorage.getUserCookie() ?? "";
    } else if (await _securityService.isLoggedIn()) {
      var userToken = (await _securityStorage.getUserToken())!;
      data.headers[HttpHeaders.authorizationHeader] = 'Bearer ${userToken.token}';
    }

    return data;
  }

  @override
  Future<ResponseData> interceptResponse({required ResponseData data}) async {
    if (_xdkConfig.securityConfig?.useCookieAuth ?? false) {
      var cookie = data.headers?[HttpHeaders.setCookieHeader];

      if (!cookie.isNullOrEmpty) {
        var idx = cookie!.indexOf(';');
        var cookieContent = idx == -1 ? cookie : cookie.substring(0, idx);

        _securityStorage.saveUserCookie(cookieContent);
      }
    }

    return data;
  }
}
