import 'store_actions_config.dart';

/// Configuração do store.
class StoreConfig<T> {
  /// Nome da propriedade que representa a chave da lista.
  /// Obs: Utilizado apenas para listas estáticas (locais).
  String? listKeyProperty;

  /// Nome da propriedade que representa o valor da lista.
  /// Obs: Utilizado apenas para listas estáticas (locais).
  /// - Essa propriedade pode receber um template no padrão:
  /// '{{': inicia o template
  /// '}}': finaliza o template
  /// '\[\[': inicia a tag com o nome do campo do objeto
  /// '\]\]': finaliza a tag com o nome do campo do objeto
  /// - Exemplo:
  ///     - `{{\[\[nomeCampo1]], siga para \[\[nomeCampo2]]}}`
  String? listValueProperty;

  /// Items estáticos (locais).
  /// Caso preenchido, todas as requisições serão feitas a esse vetor.
  List<T> items = <T>[];

  /// URL base.
  /// No caso padrão será o nome do controller.
  ///     - Ex: Para o controle UsuariosController na rota /api/usuarios/... deverá ser informado o valor "usuarios".
  /// Também pode ser informada uma URL completa (absoluta) para casos especiais.
  /// Neste caso a URL configurada como base da aplicação será ignorada e para as requisições deste store, essa URL será utilizada.
  /// Obs: Obrigatório iniciar com "{protocolo}://" aonde protocolo pode ser "http", "https", "ftp", etc.
  ///     - Ex: "https://servidor-externo.com/api-enderecos/cep"
  String? baseUrl;

  /// Actions.
  /// Permite configurar os nomes das actions, caso não sigam o padrão.
  StoreActionsConfig actions = StoreActionsConfig();

  StoreConfig({this.baseUrl});
}
